@@ -6,7 +6,8 @@
 #' @keywords internal
 serialize_parse_data_flattened <- function(flattened_pd, start_line = 1) {
   flattened_pd$lag_newlines[1] <- start_line - 1
-  res <- with(flattened_pd,
+  res <- with(
+    flattened_pd,
     paste0(
       collapse = "",
       map(lag_newlines, add_newlines), map(lag_spaces, add_spaces), text
