@@ -11,7 +11,7 @@
 #' @keywords internal
 transform_files <- function(files, transformers, include_roxygen_examples) {
   transformer <- make_transformer(transformers, include_roxygen_examples)
-  max_char <- min(max(nchar(files), 0), 80)
+  max_char <- min(max(nchar(files), 0), getOption("width"))
   if (length(files) > 0L) {
     cat("Styling ", length(files), " files:\n")
   }
@@ -215,7 +215,6 @@ parse_transform_serialize_r <- function(text, transformers, warn_empty = TRUE) {
 #' @importFrom purrr flatten
 #' @keywords internal
 apply_transformers <- function(pd_nested, transformers) {
-
   transformed_updated_multi_line <- post_visit(
     pd_nested,
     c(transformers$initialize, transformers$line_break, set_multi_line, update_newlines)
