@@ -9,7 +9,18 @@ fac[
   a,
   b
 ]
+
 fac[
   a,
   b
 ]
+
+fac[
+  , `:`(a = b)
+]
+
+fac[
+  , `:`(a = b)
+]
+
+fac[, `:`(a = c)]
